-- Per-machine config file
--	Make a copy of this file named "conf.lua"
--	and set options there.
local conf = {}


conf.screenshot_dir = "screenshot_target_dir"

-- See bar.shortcuts
conf.app_icon_dir = "theme_icon_dir"


-- Mount root dir for system mount keybind.
-- Must end with a /.
conf.user_mount_root = "user_mount_path"


-- Should tag indicators be updated continuously?
--  Once every two seconds. The timer is in desktop.init
conf.continuous_tag_updates = true

-- Wallpaper configuration
-- Wallpapers are managed by the desktop module.
-- Static walls will be set in desktop/init.lua; dynamic, time-based
-- walls will be managed by desktop/wallpaper.lua
--
-- Static: a path to an image file
conf.wallpaper = "path-to-wallpaper.png"
--
-- Dynamic: a table of files and times
-- {file = "path", start_time = {hour, minute}}
--[[
conf.wallpaper = {
	{ file = "morning-file.png", start_time = {04, 00} },
	{ file = "noon-file.png", start_time = {11, 00} },
	{ file = "night-file.png", start_time = {19, 00} },
}
]]--


-- Enable/disable the battery and backlight control and widgets
conf.battery_enabled = false
conf.backlight_enabled = false

-- Fixed width of all clienticons in tasklist
conf.clienticon_width = 50

-- The position of the bar on each screen
conf.bar_position = "bottom"
-- Bar size in dpi
conf.bar_height = 44
-- Size of bar widget margins
conf.bar_margin = 3

-- A list of shortcuts in the bar.
--[[  defined as follows:
conf.bar_shortcuts = {
	{
		"command-to-run",
		"icon-file" (relative to conf.app_icon_dir)
	},
}
]]--
conf.bar_shortcuts = {}



-- Enable/Disable the MPC widget
conf.mpc_enabled = true

-- MPC server. Usually localhost.
--  If your MPC server has a password, use the following format: "passwd@host"
conf.mpd_host = "localhost"
-- Fixed width of the mpc widget
conf.mpc_width = 250


-- Preferred terminal.
conf.terminal = "kitty"

-- Preferred browser.
conf.browser = "firefox-developer-edition --new-tab"


-- The pulse sink volume widgets and keybinds should use.
--   To use the default, keep this value an empty string.
--   Applies the --sink option to pamixer in wrapper.volume
conf.pamixer_sink = ""



-- Table of layouts.
-- This is not handled by the regular awesomewm facility.
-- It's handled by layoutmanager, to add extra features.
--
-- This table is a table of tables.
-- (see the example)
-- the tables it contains are groups, switched through using the main
-- layout keybind.
--
-- groups contain one or more layouts. The first layout is selected by default,
-- and is used whenever that group is seleced.
-- Likewise, the first group is the default, and is applied to all tags at the start.
conf.layouts = {
	{
		awful.layout.suit.tile.left,
		awful.layout.suit.tile,
	},
	{
		awful.layout.suit.fair,
		awful.layout.suit.fair.horizontal,
	},
	{
		awful.layout.suit.floating,
	}

	--awful.layout.suit.tile.bottom,
	--awful.layout.suit.tile.top,
	--awful.layout.suit.spiral,
	--awful.layout.suit.spiral.dwindle,
	--awful.layout.suit.max,
	--awful.layout.suit.max.fullscreen,
	--awful.layout.suit.magnifier,
	--awful.layout.suit.corner.nw,
	--awful.layout.suit.corner.ne,
	--awful.layout.suit.corner.sw,
	--awful.layout.suit.corner.se,
}

-- Order matters!
--  The first entry will be activated at startup.
--  Use ibus engine to get the current engine name.
--  DUPLICATE IBUS_ENGINE VALUES WILL BREAK THE SWITCHER!
--
-- Some overlay layours require a switch to en:us first.
--  For example, switching from russian (xkb remap) to pinyin (ibus overlay on en:us)
--  will not work.
--
conf.ibus_language_list = {
	{
		title = "English",
		indicator_code = "en",
		ibus_engine = "xkb:us::eng",
	},
	{
		title = "Russian",
		indicator_code = "ru",
		ibus_engine = "xkb:ru::rus"
	},
	{
		title = "Mathwriter",
		indicator_code = "∫x",
		ibus_engine = "table:mathwriter-ibus",
		requires_engine = "xkb:us::eng"
	}
}

-- Run these commands, in this order, when awesome starts.
conf.startup_commands = {
	"ibus-daemon --daemonize --replace --xim",
	"keepassxc",
	"mictray"
}

return conf
