-- AwesomeWM modules
gears = require("gears")
awful = require("awful")
naughty = require("naughty")
beautiful = require("beautiful")
menubar = require("menubar")
wibox = require("wibox")
require("awful.autofocus")
conf_dir = gears.filesystem.get_configuration_dir()


-- A "relative require" hack. Does the same thing as `require`,
-- But takes a relative path.
-- Called with req_rel(..., "module")
function req_rel(ddd, modname)
	local parent_folder = (ddd):match("(.-)[^%.]+$")
	return require(parent_folder .. modname)
end

-- Quick debug function
debug_message = function(msg)
	naughty.notify({title = "Debug message:", text = tostring(msg)})
end

-- Order matters.
conf = require("conf")
beautiful.init(require("theme"))
core = require("core")


-- Load key bindings
local binds = require("binds")
local keys = binds.keys
local buttons = binds.buttons

-- Load modules
modules = {}
for k, v in ipairs({
	"mpc",
	"ibus",
	"volume",
	"launcher",
	"simple_widgets",
	"screenshot",
	"i3lock"
}) do
	modules[v] = require("modules." .. v)

	-- If module defines keybinds, load keybinds.
	if (modules[v]["keybinds"] ~= nil) then
		keys = gears.table.join(
			keys,
			modules[v]["keybinds"]
		)
	end
end

-- Run all module init methods
for _, mod in ipairs(modules) do
	if (mod["init"] ~= nil) then
		mod["init"]()
	end
end


-- Finalize keybinds
root.keys(keys)
root.buttons(buttons)



-- Autostart
for i, v in ipairs(conf.startup_commands) do
	awful.spawn(v)
end


-- Enable hotkeys help widget for VIM and other apps
-- when client with a matching name is opened:
--require("awful.hotkeys_popup.keys")

core.start()

-- Check for errors
dofile(conf_dir .. "errors.lua")

menubar.utils.terminal = conf.terminal

-- Load client methods
awful.rules.rules = require("clients.rules")
dofile(conf_dir .. "clients/signals.lua")
require("clients.render")
